<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>ORFDialogBase</name>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="34"/>
        <source>find_dialog_caption</source>
        <translation>Поиск открытых рамок считывания</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="40"/>
        <source>find_dialog_wit</source>
        <translation>Поиск открытых рамок считывания в последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="59"/>
        <source>strand_group</source>
        <translation>Направление</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="71"/>
        <source>strand_both</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="81"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="84"/>
        <source>strand_direct_wit</source>
        <translation>Искать только в прямой последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="87"/>
        <source>strand_direct_label</source>
        <translation>Прямые</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="100"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="103"/>
        <source>strand_complement_wit</source>
        <translation>Искать только в комплeментарной последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="106"/>
        <source>strand_complement_label</source>
        <translation>комплeментарные</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="125"/>
        <source>param_group</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="139"/>
        <source>min_len_label</source>
        <translation>Мин длина, нукл</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="188"/>
        <source>must_fit_label</source>
        <translation>Терминатор внутри региона</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="201"/>
        <source>must_init_label</source>
        <translation>Старт-кодон обязателен</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="220"/>
        <source>allow_alternative_label</source>
        <translation>Альтернативные старт-кодоны</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="246"/>
        <source>find_all_wit</source>
        <translation>Начать поиск ORF</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="249"/>
        <source>find_all_button</source>
        <translation>Искать</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="290"/>
        <source>hide_button_wit</source>
        <translation>Остановить поиск и закрыть диалог</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="293"/>
        <source>close_button</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="265"/>
        <source>save_as_features_tt</source>
        <translation>Сохранить результаты как аннотации</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="268"/>
        <source>save_as_features_wit</source>
        <translation>Сохранить результаты как аннотации</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="325"/>
        <source>clear_list_button</source>
        <translation>Сбросить результаты</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="391"/>
        <source>rstart_label</source>
        <translation>Начало региона поиска: </translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="427"/>
        <source>rend_label</source>
        <translation>Конец региона поиска: </translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="133"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="136"/>
        <location filename="../src/ORFQuery.cpp" line="220"/>
        <location filename="../src/ORFWorker.cpp" line="60"/>
        <source>min_len_tip</source>
        <translation>Не учитывать ORF короче указанной длины</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="182"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="185"/>
        <location filename="../src/ORFWorker.cpp" line="61"/>
        <source>must_fit_tip</source>
        <translation>Не учитывать ORF продолжающиеся за пределы поcледовательности (или региона поиска).</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="195"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="198"/>
        <location filename="../src/ORFQuery.cpp" line="221"/>
        <location filename="../src/ORFWorker.cpp" line="62"/>
        <source>must_init_tip</source>
        <translation>Допускать или нет ORF начинающиеся с любого кодона кроме терминатора.
Т.е. искать ORF от одного терминатора до другого (или от границы региона до ближайшего терминатора).</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="214"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="217"/>
        <location filename="../src/ORFQuery.cpp" line="222"/>
        <location filename="../src/ORFWorker.cpp" line="63"/>
        <source>allow_alt_tip</source>
        <translation>Учитывать ORF начинающиеся с неканонических стартовых кодонов,
указанных в выбранной таблице трансляции.</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="65"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="68"/>
        <source>strand_both_wit</source>
        <translation>Искать в прямой и комплeментарной последовательностях</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="470"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="473"/>
        <source>sel_bt_tip</source>
        <translation>Искать в селектированном регионе</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="483"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="486"/>
        <source>pv_bt_tip</source>
        <translation>Установить регион поиска к отображаемому в панораме</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="496"/>
        <location filename="../src/ui/ORFDialogUI.ui" line="499"/>
        <source>seq_bt_tip</source>
        <translation>Искать во всей последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="271"/>
        <source>save_as_annotations</source>
        <translation>Сохранить результаты</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="371"/>
        <source>region</source>
        <translation>Регион</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="376"/>
        <source>compl</source>
        <translation>Стренд</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="381"/>
        <source>len</source>
        <translation>Длина</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="476"/>
        <source>Selection range</source>
        <translation>Выбранный регион</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="489"/>
        <source>Overview range</source>
        <translation>Видимый регион</translation>
    </message>
    <message>
        <location filename="../src/ui/ORFDialogUI.ui" line="502"/>
        <source>Sequence range</source>
        <translation>Вся последовательность</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Annotate as</source>
        <translation type="obsolete">Аннотации</translation>
    </message>
    <message>
        <source>Name of the result annotations marking found ORFs</source>
        <translation type="obsolete">Имя аннотации для разметки найденных ORF</translation>
    </message>
    <message>
        <source>Search in</source>
        <translation type="obsolete">Направление</translation>
    </message>
    <message>
        <source>Which strands should be searched: direct, complement or both.</source>
        <translation type="obsolete">В каких стрендах последовательности следует искать ORF: прямых, комплементарных или всех.</translation>
    </message>
    <message>
        <source>Genetic code</source>
        <translation type="obsolete">Код трансляции</translation>
    </message>
    <message>
        <source>Which genetic code should be used for translating the input nucleotide sequence.</source>
        <translation type="obsolete">Выбор генетического кода (таблицы трансляции в протеины) для входных последовательностей</translation>
    </message>
    <message>
        <source>Min length</source>
        <translation type="obsolete">Мин длина</translation>
    </message>
    <message>
        <source>Require init codon</source>
        <translation type="obsolete">Старт-кодон обязателен</translation>
    </message>
    <message>
        <source>Allow alternative codons</source>
        <translation type="obsolete">Альтернативные кодоны</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::ORFPrompter</name>
    <message>
        <location filename="../src/ORFWorker.cpp" line="119"/>
        <source> from %1</source>
        <translation> из %1</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="130"/>
        <source>, allow ORFs &lt;u&gt;starting with any codon&lt;/u&gt; other than terminator</source>
        <translation>, допускать ORF &lt;u&gt;начинающиеся с любого кодона&lt;/u&gt; кроме терминатора</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="132"/>
        <source>, take into account &lt;u&gt;alternative start codons&lt;/u&gt;</source>
        <translation>, принимать во внимание &lt;u&gt;альтернативные старт-кодоны&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="135"/>
        <source>, &lt;u&gt;ignore non-terminated&lt;/u&gt; ORFs</source>
        <translation>, &lt;u&gt;исключать нетерминированные&lt;/u&gt; ORF</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="152"/>
        <source>For each nucleotide sequence&lt;u&gt;%1&lt;/u&gt;, find ORFs in &lt;u&gt;%2&lt;/u&gt; using the &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Detect only ORFs &lt;u&gt;not shorter than %4 bps&lt;/u&gt;%5.&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%6&lt;/u&gt;.</source>
        <translation>Искать ORF в каждой нуклеотидной последовательности&lt;u&gt;%1&lt;/u&gt;. Рассматривать &lt;u&gt;%2 стренды&lt;/u&gt;, используя &lt;u&gt;%3&lt;/u&gt;.&lt;br&gt;Учитывать только ORF &lt;u&gt;не короче чем %4 нк&lt;/u&gt;%5.&lt;br&gt;Выдать список найденых ORF аннотированных как &lt;u&gt;%6&lt;/u&gt;.</translation>
    </message>
</context>
<context>
    <name>U2::LocalWorkflow::ORFWorker</name>
    <message>
        <location filename="../src/ORFWorker.cpp" line="242"/>
        <source>Found %1 ORFs</source>
        <translation>Найдено %1 ORF регионов</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="44"/>
        <source>Input sequences</source>
        <translation>Анализируемая последовательность</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="46"/>
        <source>ORF annotations</source>
        <translation>ORF аннотации</translation>
    </message>
    <message>
        <source>Search in</source>
        <translation type="obsolete">Направление</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="59"/>
        <source>Genetic code</source>
        <translation>Код трансляции</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="61"/>
        <source>Require stop codon</source>
        <translation>Стоп-кодон обязателен</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="62"/>
        <source>Require init codon</source>
        <translation>Старт-кодон обязателен</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="63"/>
        <source>Allow alternative codons</source>
        <translation>Альтернативные кодоны</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="189"/>
        <source>ORF: result name is empty, default name used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="194"/>
        <source>ORF: Incorrect value: min-length must be greater then zero</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ORF Marker</source>
        <translation type="obsolete">Поиск ORF</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="140"/>
        <source>both strands</source>
        <translation>все</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="141"/>
        <source>direct strand</source>
        <translation>только прямые</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="142"/>
        <source>complement strand</source>
        <translation>только комплементарные</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="57"/>
        <source>Name of the result annotations marking found ORFs</source>
        <translation>Имя аннотации для разметки найденных ORF</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="45"/>
        <source>A nucleotide sequence to search ORFs in. Protein sequences are skipped.</source>
        <translation>Нуклеотидные последовательности для поиска ORF. Протеиновые последовательности допустимы но игнорируются.</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="47"/>
        <source>A set of annotations marking ORFs found in the sequence.</source>
        <translation>Набор аннотированных регионов для найденных ORF.</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="58"/>
        <source>Which strands should be searched: direct, complement or both.</source>
        <translation>В каких стрендах последовательности следует искать ORF: прямых, комплементарных или всех.</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="59"/>
        <source>Which genetic code should be used for translating the input nucleotide sequence.</source>
        <translation>Выбор генетического кода (таблицы трансляции в протеины) для входных последовательностей</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="74"/>
        <source>ORF marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="75"/>
        <source>Finds Open Reading Frames (ORFs) in each supplied nucleotide sequence, stores found regions as annotations.&lt;p&gt;Protein sequences are skipped if any supplied to input.&lt;p&gt;&lt;dfn&gt;ORFs are DNA sequence regions that could potentially encode a protein, and usually give a good indication of the presence of a gene in the surrounding sequence.&lt;/dfn&gt;&lt;/p&gt;&lt;p&gt;In the sequence, ORFs are located between a start-code sequence (initiation codon) and a stop-code sequence (termination codon), defined by the selected genetic code.&lt;/p&gt;</source>
        <translation>Поиск открытых рамок считывания (ОRF). ORF ищутся в каждой нуклеотидной последовательности, поданной на вход задачи; найденные регионы выдаются как набор аннотаций. 
&lt;p&gt; Протеиновые последовательности на входе допустимы но не обрабатываются.</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="57"/>
        <source>Annotate as</source>
        <translation>Аннотации</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="60"/>
        <source>Min length</source>
        <translation>Мин длина</translation>
    </message>
    <message>
        <source> bp</source>
        <translation type="obsolete">нк</translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="195"/>
        <source>Incorrect value: min-length must be greater then zero</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ORFWorker.cpp" line="219"/>
        <source>Bad sequence supplied to ORFWorker: %1</source>
        <translation>Неверная последовательность для поиска ORF: %1</translation>
    </message>
</context>
<context>
    <name>U2::ORFDialog</name>
    <message>
        <location filename="../src/ORFDialog.cpp" line="190"/>
        <source>cancel_button</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="190"/>
        <source>close_button</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="208"/>
        <source>progress_%1%</source>
        <translation>Прогресс %1</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="210"/>
        <source>%1_results_found.</source>
        <translation>Найдено %1</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="260"/>
        <source>warning</source>
        <translation>Подтверждение</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="260"/>
        <source>results_list_not_empty_ask_clear</source>
        <translation>Сбросить предыдущие результаты?</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="151"/>
        <source>start_codons</source>
        <translation>Старт-кодоны</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="152"/>
        <source>alt_start_codons</source>
        <translation>Альтернативные кодоны</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="153"/>
        <source>stop_codons</source>
        <translation>Стоп-кодоны</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="388"/>
        <source>complem_strand</source>
        <translation>комплeментарный</translation>
    </message>
    <message>
        <location filename="../src/ORFDialog.cpp" line="388"/>
        <source>direct_strand</source>
        <translation>прямой</translation>
    </message>
</context>
<context>
    <name>U2::ORFMarkerPlugin</name>
    <message>
        <location filename="../src/ORFMarkerPlugin.cpp" line="35"/>
        <source>orfname</source>
        <translation>Поиск ORF</translation>
    </message>
    <message>
        <location filename="../src/ORFMarkerPlugin.cpp" line="35"/>
        <source>orfdesc</source>
        <translation type="unfinished">ORF: Поиск открытых рамок считывания</translation>
    </message>
</context>
<context>
    <name>U2::ORFQDActor</name>
    <message>
        <source>both strands</source>
        <translation type="obsolete">все стренды</translation>
    </message>
    <message>
        <source>direct strand</source>
        <translation type="obsolete">только прямые стренды</translation>
    </message>
    <message>
        <source>complement strand</source>
        <translation type="obsolete">только комплементарные стренды</translation>
    </message>
    <message>
        <source>, allow ORFs &lt;u&gt;starting with any codon&lt;/u&gt; other than terminator</source>
        <translation type="obsolete">, допускать ORF начинающиеся с любого кодона  кроме терминатора</translation>
    </message>
    <message>
        <source>, take into account &lt;u&gt;alternative start codons&lt;/u&gt;</source>
        <translation type="obsolete">, принимать во внимание альтернативные старт-кодоны</translation>
    </message>
    <message>
        <source>Finds ORFs in &lt;u&gt;%1&lt;/u&gt; using the &lt;u&gt;%2&lt;/u&gt;.&lt;br&gt;Detects only ORFs &lt;u&gt;not shorter than %3, not longer than %4&lt;/u&gt;%5.&lt;br&gt;Outputs the list of found regions annotated as &lt;u&gt;%6&lt;/u&gt;.</source>
        <translation type="obsolete">Искать ORF в %1, используя %2.&lt;br&gt;Рассматривать результаты не длиннее %3, не короче &lt;u&gt;%4&lt;/u&gt; %5. Сохранить список найденных регионов аннотированных как %6.</translation>
    </message>
    <message>
        <source>Finds Open Reading Frames (ORFs) in supplied nucleotide sequence, stores found regions as annotations.&lt;p&gt;Protein sequences are skipped if any.&lt;p&gt;&lt;dfn&gt;ORFs are DNA sequence regions that could potentially encode a protein, and usually give a good indication of the presence of a gene in the surrounding sequence.&lt;/dfn&gt;&lt;/p&gt;&lt;p&gt;In the sequence, ORFs are located between a start-code sequence (initiation codon) and a stop-code sequence (termination codon), defined by the selected genetic code.&lt;/p&gt;</source>
        <translation type="obsolete"> Поиск открытых рамок считывания (ОRF) в заданной нуклеотидной последовательности, найденные регионы сохраняются как набор аннотаций.&lt;p&gt;Протеиновые последовательности не обрабатываются.&lt;p&gt;</translation>
    </message>
    <message>
        <source> bp</source>
        <translation type="obsolete">нк</translation>
    </message>
</context>
<context>
    <name>U2::ORFViewContext</name>
    <message>
        <location filename="../src/ORFMarkerPlugin.cpp" line="70"/>
        <source>Find ORFs...</source>
        <translation type="unfinished">ORF: Искать рамки считывания</translation>
    </message>
</context>
<context>
    <name>U2::QDORFActor</name>
    <message>
        <location filename="../src/ORFQuery.cpp" line="91"/>
        <source>both strands</source>
        <translation>все стренды</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="93"/>
        <source>direct strand</source>
        <translation>только прямые стренды</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="95"/>
        <source>complement strand</source>
        <translation>только комплементарные стренды</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="110"/>
        <source>, allow ORFs &lt;u&gt;starting with any codon&lt;/u&gt; other than terminator</source>
        <translation>, допускать ORF начинающиеся с любого кодона  кроме терминатора</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="112"/>
        <source>, take into account &lt;u&gt;alternative start codons&lt;/u&gt;</source>
        <translation>, принимать во внимание альтернативные старт-кодоны</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="123"/>
        <source>Finds ORFs in &lt;u&gt;%1&lt;/u&gt; using the &lt;u&gt;%2&lt;/u&gt;.&lt;br&gt;Detects only ORFs &lt;u&gt;not shorter than %3, not longer than %4&lt;/u&gt;%5.</source>
        <translation>Искать ORF в %1, используя %2.&lt;br&gt;Рассматривать результаты не длиннее %3, не короче &lt;u&gt;%4&lt;/u&gt; %5.</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="164"/>
        <source>ORF find</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="209"/>
        <source>ORF</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="210"/>
        <source>Finds Open Reading Frames (ORFs) in supplied nucleotide sequence, stores found regions as annotations.&lt;p&gt;Protein sequences are skipped if any.&lt;p&gt;&lt;dfn&gt;ORFs are DNA sequence regions that could potentially encode a protein, and usually give a good indication of the presence of a gene in the surrounding sequence.&lt;/dfn&gt;&lt;/p&gt;&lt;p&gt;In the sequence, ORFs are located between a start-code sequence (initiation codon) and a stop-code sequence (termination codon), defined by the selected genetic code.&lt;/p&gt;</source>
        <translation> Поиск открытых рамок считывания (ОRF) в заданной нуклеотидной последовательности, найденные регионы сохраняются как набор аннотаций.&lt;p&gt;Протеиновые последовательности не обрабатываются.&lt;p&gt;</translation>
    </message>
    <message>
        <source>Search in</source>
        <translation type="obsolete">Направление</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="218"/>
        <source>Which strands should be searched: direct, complement or both.</source>
        <translation>В каких стрендах последовательности следует искать ORF: прямых, комплементарных или всех.</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="219"/>
        <source>Genetic code</source>
        <translation>Код трансляции</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="219"/>
        <source>Which genetic code should be used for translating the input nucleotide sequence.</source>
        <translation>Выбор генетического кода (таблицы трансляции в протеины) для входных последовательностей.</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="220"/>
        <source>Min length</source>
        <translation>Мин длина</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="221"/>
        <source>Require init codon</source>
        <translation>Старт-кодон обязателен</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="222"/>
        <source>Allow alternative codons</source>
        <translation>Альтернативные кодоны</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="223"/>
        <source>Max length</source>
        <translation>Макс длина</translation>
    </message>
    <message>
        <location filename="../src/ORFQuery.cpp" line="223"/>
        <source>Maximum length of annotation allowed</source>
        <translation>Макс длина</translation>
    </message>
    <message>
        <source> bp</source>
        <translation type="obsolete">нк</translation>
    </message>
</context>
</TS>
